@@ -139,7 +139,9 @@ liqcell *	liqcell_getlinkprev(liqcell *self);
 liqcell *	liqcell_getlinknext(liqcell *self);
 liqcell *	liqcell_getlinkchild(liqcell *self);
 
-
+liqcell *	liqcell_getlinkprev_visual(liqcell *self);
+liqcell *	liqcell_getlinknext_visual(liqcell *self);
+liqcell *	liqcell_getlinkchild_visual(liqcell *self);
 //######################################################################### searching
 
 //liqcell*  liqcell_findfirst(liqcell *self,char *query);
@@ -272,7 +274,8 @@ int    	liqcell_getkineticx(liqcell *self);
 int    	liqcell_getkineticy(liqcell *self);
 
 void 	liqcell_forceinboundparent(liqcell *self);
-
+int     liqcell_ensurevisible(liqcell *self);
+int     liqcell_ensurevisible_centred(liqcell *self);
 //######################################################################### Misc Functions
 
 void 	liqcell_zorder_totop(liqcell *self);  // moves the cell to the top of the zorder, NULL function at present
