@@ -581,6 +581,39 @@ liqcell *liqcell_getlinknext(liqcell *self)
 	return self->linknext;
 }
 
+liqcell *liqcell_getlinkprev_visual(liqcell *self)
+{
+	liqcell *c = self->linkprev;
+	while(c)
+	{
+		if(liqcell_getflagvisual(c))return c;
+		c=c->linkprev;
+	}
+	return NULL;
+}
+
+liqcell *liqcell_getlinknext_visual(liqcell *self)
+{
+	liqcell *c = self->linknext;
+	while(c)
+	{
+		if(liqcell_getflagvisual(c))return c;
+		c=c->linknext;
+	}
+	return NULL;
+}
+
+liqcell *liqcell_getlinkchild_visual(liqcell *self)
+{
+	liqcell *c = self->linkchild;
+	while(c)
+	{
+		if(liqcell_getflagvisual(c))return c;
+		c=c->linknext;
+	}
+	return NULL;
+}
+
 /**
  * Return the linked child of the parent provided.
  * @param self The parent liqcell
@@ -1002,7 +1035,7 @@ liqcell* liqcell_child_insertsorted(liqcell *self,liqcell * ch)
 		liqcell *xx=self->linkchild;
 		while(xx)
 		{
-			if(xx->name && strcmp(sa->name,xx->name)< 0)
+			if(xx->name && strcasecmp(sa->name,xx->name)< 0)
 			{
 				// insert it here...
 				//liqapp_log("insert before '%s' < '%s'",sa->name,xx->name);
@@ -1067,7 +1100,7 @@ liqcell* liqcell_child_insertsortedbyname(liqcell *self,liqcell * ch,int sortpos
 		{
 			if(xx->name)
 			{
-				int res=strcmp(sa->name,xx->name);
+				int res=strcasecmp(sa->name,xx->name);
 				if(!sortpositive)res=-res;
 				if(res < 0)
 				{
@@ -1527,6 +1560,13 @@ int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
 {
 	int (*event_handler)(liqcell *cell,void *args,void *context);
 	liqcell *p=self;
+	
+	// 20090618_020708 lcuk : make sure we keep hold of reference for this part
+	// 20090618_020717 lcuk : i just realised i want to collapse all the tree from within an event
+	// 20090618_020733 lcuk : and without this guard, the usagecount should hit 0 and the memory released
+	// 20090618_020808 lcuk : but some of the time i carry on looping
+	//liqcell_hold(self);
+	
 	//while(p)
 	{
 		liqcell *c=p->linkchild;
@@ -1544,14 +1584,23 @@ int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
 					event_handler = c->data;
 					if(event_handler)
 					{
+						
+						//if(context) liqcell_hold(context);
+
+						
 						// Run/Execute the handler
 						int res = event_handler(self,args,context);
+						
+						//if(context) liqcell_release(context);
+						
+						
 						if(res)
 						{
 							// event was handled...
+							//liqcell_release(self);
 							return res;
 						}
-						//return res;
+						return res;		// if the event existed, we run it, no consequence, later, inc ref count and allow recursive multiple event chains
 					}
 					//return 0;
 				}
@@ -1560,6 +1609,7 @@ int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
 		}
 		//p=liqcell_getcontent(p);
 	}
+	//liqcell_release(self);
 	return 0;
 }
 
@@ -1604,6 +1654,143 @@ int liqcell_isclass(liqcell *self,char *classname)
 
 
 
+
+
+
+//##############################################################
+//##############################################################
+//##############################################################
+
+
+
+
+static int lowest(int a,int b)
+{
+	if(abs(a)<abs(b))
+	{
+		liqapp_log("lowest %i :: %i = a %i",a,b,a);
+		return a;
+	}
+	liqapp_log("lowest %i :: %i = b %i",a,b,b);
+	return b;
+}
+
+
+static int dimension_ensurevisible( int rs,int re,    int ps,int pe, int ss,int se)
+{
+	// calculate the minimal adjustment within a dimension required to ensure S is visible through the portal that R provides
+	// the adjustment will be applied to P upon returning from this function
+	// to slide the rule along so s is visible :)
+	//ss += ps;	// start by adjusting 
+	//se += pe;
+	liqapp_log("dim ol: r(%i,%i)   p(%i,%i)    s(%i,%i)",   rs,re,     ps,pe,     ss,se);
+	if(re<=ss)
+	{
+		// S is way below, lets adjust
+		return lowest(ss-rs,se-re);
+	}
+	if(rs<=ss)
+	{
+		// S is actually somewhat visible
+		// but we might be chopping off the bottom of it
+		if(re<=se)
+		{
+			return lowest(ss-rs,se-re);
+		}
+		// otherwise we let it be, floating somewhere within
+		return 0;
+	}
+
+	// S is partially or entirely above us
+	return lowest(ss-rs,se-re);
+}
+
+
+
+
+int liqcell_ensurevisible(liqcell *self)
+{
+	liqapp_log("ensure: %s",self->name);
+	int xs=self->x;
+	int xe=self->x+self->w;
+	int ys=self->y;
+	int ye=self->y+self->h;
+	
+	liqcell *p=liqcell_getlinkparent(self);
+	//while(p)
+	if(p)
+	{
+		liqcell *r=liqcell_getlinkparent(p);
+		if(r)
+		{
+			liqapp_log("trying in : %s",p->name);
+			xs+=p->x;
+			xe+=p->x;
+			ys+=p->y;
+			ye+=p->y;
+
+			//
+			int ax = -dimension_ensurevisible(0,r->w,   p->x,p->x+p->w,   xs,xe);
+			int ay = -dimension_ensurevisible(0,r->h,   p->y,p->y+p->h,   ys,ye);
+
+
+			liqapp_log("gave me : a(%i,%i)",  ax,ay);
+
+			liqcell_adjustpos(p,ax,ay);
+			xs-=ax;
+			xe-=ax;
+			ys-=ay;
+			ye-=ay;
+
+		}
+		//p=r;
+	}
+	return 0;
+}
+
+
+int liqcell_ensurevisible_centred(liqcell *self)
+{
+	liqapp_log("ensure: %s",self->name);
+	int xs=self->x;
+	int xe=self->x+self->w;
+	int ys=self->y;
+	int ye=self->y+self->h;
+	
+	liqcell *p=liqcell_getlinkparent(self);
+	//while(p)
+	if(p)
+	{
+		liqcell *r=liqcell_getlinkparent(p);
+		if(r)
+		{
+			liqapp_log("trying in : %s",p->name);
+			xs+=p->x;
+			xe+=p->x;
+			ys+=p->y;
+			ye+=p->y;
+
+			//
+			int ax = -dimension_ensurevisible(r->w*0.5,r->w*0.5,   p->x,p->x+p->w,   xs,xe);
+			int ay = -dimension_ensurevisible(r->h*0.5,r->h*0.5,   p->y,p->y+p->h,   ys,ye);
+
+
+			liqapp_log("gave me : a(%i,%i)",  ax,ay);
+
+			liqcell_adjustpos(p,ax,ay);
+			xs-=ax;
+			xe-=ax;
+			ys-=ay;
+			ye-=ay;
+
+		}
+		//p=r;
+	}
+	return 0;
+}
+
+
+
 //#########################################################################
 //#########################################################################
 //######################################################################### cell test
