@@ -187,6 +187,7 @@ while(mainthread_inprogress>1);
 					
 					
 					
+					
 					liqapp_log("http about to download '%s' into '%s'",fn,cachefn);
 					// doesn't exist yet
 					if(!liqapp_pathexists("liqbasecache"))
@@ -243,11 +244,13 @@ while(mainthread_inprogress>1);
 
 
 				liqcell_setdirty(self,1);
+				liqcell_release(self);
 			}
 			else
 			{
 				// clear the utility of the "loading" image
 				liqcell_setimage( self, NULL );
+				liqcell_release(self);
 
 			}
 
@@ -548,7 +551,34 @@ __tz_one("sizeok2");
 __tz_one("showndone");
 
 	// try it..
-	liqcell_handlerrun(self,"paint",NULL);
+	
+	
+	if(liqcell_handlerfind(self,"paint"))
+	{
+
+		// 20090621_120251 lcuk : paint NEEDS to pass a valid args with valid graph object here, shit it doesnt
+
+		vgraph *graph = vgraph_new();
+		vgraph_setscaleaspectlock(graph,  1);
+		
+		vgraph_setcliprect(graph, cr           );
+		//vgraph_settarget(graph,   cr->surface  );
+		vgraph_settarget_coord( graph,  x,y,w,h      );
+		vgraph_setwindow( graph,  (self)       );
+		//vgraph_setwindow_coord( graph,  x,y,w,h      );
+
+		liqcellpainteventargs paintargs;
+		//paintargs.cr = liqcanvas_getcliprect();
+		paintargs.graph = graph;
+		paintargs.runfast=0;
+		
+		liqcell_handlerrun(self,"paint",&paintargs);
+		
+		//vgraph_setwindow( graph,  NULL       );
+		//vgraph_settarget(graph,   NULL  );
+		//vgraph_setcliprect(graph,   NULL  );
+		vgraph_release(graph);
+	}
 	
 	// 20090526_230043 lcuk : todo: test whether bailing if painting "dealt with" harms anything
 	// 20090526_230103 lcuk : i dont think it does right now
@@ -593,34 +623,52 @@ __tz_one("backdone");
 		if(fn && (liqapp_fileexists(fn) || ishttp(fn)))
 		{
 		
-		
-		
-			// i need to do the following:
-			// set a "please wait, loading" icon
-			// create a low priority thread with this object and nothing else
-			
-			if(!easypaint_isloading_image)
+			// 20090619_125841 lcuk : do a quick check in the image cache
+			// 20090619_125850 lcuk : if the file exists, then we just grab that :)
+			int imageallowalpha = liqcell_propgeti(self,"imageallowalpha",1);
+			liqimage *imgnew = liqimage_cache_lookuponly(fn,0,0, imageallowalpha );
+			if(imgnew)
 			{
-				//easypaint_isloading_image=liqimage_newfromfile("media/sun.png",0,0,0);
-				easypaint_isloading_image=liqimage_newfromfile("/usr/share/liqbase/media/pleasewait.png",0,0,0);
-			}
-			if(easypaint_isloading_image)
-			{
-				// only if we have a valid replacer can we do this trickery :)
-				liqcell_setimage(self, liqimage_hold(easypaint_isloading_image) );
-				// now we must start the thread off
-				pthread_t 		tid;
-				
-				//int tres=thread_createwithpriority(&tid,0,mainthread,self);
-				
-				int tres=pthread_create(&tid,NULL,mainthread,self);
-				
-				
-				if(tres)
+				liqcell_setimage( self, imgnew );
+				int isautosize = liqcell_propgeti(self,"autosize",0);
+				if(isautosize)
 				{
-					liqapp_log("thread create fail %s :: %i",fn,tres);
-					liqcliprect_release(cr);
-					return 0;
+					liqcell_setsize(self,imgnew->width,imgnew->height);
+				}
+				liqcell_setdirty(self,1);
+			}			
+			else
+			{
+				
+				// i need to do the following:
+				// set a "please wait, loading" icon
+				// create a low priority thread with this object and nothing else
+				
+				if(!easypaint_isloading_image)
+				{
+					//easypaint_isloading_image=liqimage_newfromfile("media/sun.png",0,0,0);
+					easypaint_isloading_image=liqimage_newfromfile("/usr/share/liqbase/media/pleasewait.png",0,0,0);
+				}
+				if(easypaint_isloading_image)
+				{
+					liqcell_hold(self);
+					// only if we have a valid replacer can we do this trickery :)
+					liqcell_setimage(self, liqimage_hold(easypaint_isloading_image) );
+					// now we must start the thread off
+					pthread_t 		tid;
+					
+					//int tres=thread_createwithpriority(&tid,0,mainthread,self);
+					
+					int tres=pthread_create(&tid,NULL,mainthread,self);
+					
+					
+					if(tres)
+					{
+						liqapp_log("thread create fail %s :: %i",fn,tres);
+						liqcliprect_release(cr);
+						liqcell_release(self);
+						return 0;
+					}
 				}
 			}
 			
