@@ -55,6 +55,9 @@ int liqx11info_init(liqx11info *myx11info, int pixelwidth,int pixelheight,int fu
 	
 	
 	canvas.keepalivealarmtime=10000;
+	
+
+	
 
 	myx11info->myoverlay     = NULL;
 	myx11info->mydisplay     = XOpenDisplay("");
@@ -116,15 +119,42 @@ int liqx11info_init(liqx11info *myx11info, int pixelwidth,int pixelheight,int fu
 
 
 
+	liqapp_log("x11info setting ClassHint (thanks qwerty12!)");
+	
+	char *tit = strdup(liqapp_gettitle());
+	if(!tit)
+	{
+		{ liqapp_errorandfail(-1,"x11info ClassHint, could not alloc tit"); }
+		
+	}
+	// 20090617_201322 lcuk : qwerty12 says i need a class hint as well.
+	char *t=tit;
+	while(t && *t)
+	{
+		if(*t=='-') *t='_';
+		t++;
+	}
+	
+		XClassHint classhint;
+		classhint.res_name =tit;
+		classhint.res_class=tit;
+		
+		XSetClassHint(myx11info->mydisplay, myx11info->mywindow, &classhint);
+	
+
+	
+
 
 	liqapp_log("x11info setting window properties");
 
 
 	
-	XSetStandardProperties(myx11info->mydisplay, myx11info->mywindow, liqapp_gettitle(),liqapp_gettitle(), None, NULL, 0, &myhint);
+	//XSetStandardProperties(myx11info->mydisplay, myx11info->mywindow, liqapp_gettitle(),liqapp_gettitle(), None, NULL, 0, &myhint);
+	XSetStandardProperties(myx11info->mydisplay, myx11info->mywindow, tit,tit, None, NULL, 0, &myhint);
 	
 	myx11info->mygc = XCreateGC(myx11info->mydisplay, myx11info->mywindow, 0, 0);
 
+	free(tit);
 
 	// ################### good x11 info
 	// http://www.openmash.org/lxr/source/xlib/X11/X.h?c=tk8.3#L99
@@ -1014,7 +1044,7 @@ foo:
 	{
 		// obtain new dimensions and adjust our renderer to suit   
 	}
-	else if (xev.type == 65 || xev.type == 69 || xev.type == 77)  // XShmCompletionEvent
+	else if (xev.type == 65 || xev.type == 69 || xev.type == 77|| xev.type == 77)  // XShmCompletionEvent
 	{
 		//http://www.x.org/docs/Xv/video		
 		//	XvShmPutImage has a parameter:
